@@ -1,7 +1,5 @@
 
 /*
-  $Id: utempter.c,v 1.7 2005/08/22 21:39:24 ldv Exp $
-
   Copyright (C) 2001,2002,2005  Dmitry V. Levin <ldv@altlinux.org>
 
   A privileged helper for utmp/wtmp updates.
@@ -121,7 +119,9 @@ write_uwtmp_record(const char *user, const char *term, const char *host,
 #endif
 
 	memset(&ut, 0, sizeof(ut));
+
 	memset(&tv, 0, sizeof(tv));
+	(void) gettimeofday(&tv, 0);
 
 	strncpy(ut.ut_name, user, sizeof(ut.ut_name));
 	strncpy(ut.ut_line, term, sizeof(ut.ut_line));
@@ -142,7 +142,6 @@ write_uwtmp_record(const char *user, const char *term, const char *host,
 
 	ut.ut_pid = pid;
 
-	(void) gettimeofday(&tv, 0);
 	ut.ut_tv.tv_sec = tv.tv_sec;
 	ut.ut_tv.tv_usec = tv.tv_usec;
 
@@ -160,7 +159,7 @@ write_uwtmp_record(const char *user, const char *term, const char *host,
 
 #elif defined(__FreeBSD__)
 
-	time(&ut.ut_time);
+	ut.ut_time = tv.tv_sec;
 
 	if (add)
 	{
@@ -243,11 +242,7 @@ main(int argc, const char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-#ifdef __GLIBC__
 	device = ptsname(STDIN_FILENO);
-#elif defined(__FreeBSD__)
-	device = ttyname(STDIN_FILENO);
-#endif /* __GLIBC__ || __FreeBSD__ */
 
 	if (!device)
 	{
